Overlap Module
==============

.. currentmodule:: plastro.overlap

The overlap module provides functions for computing PLASTRO overlap scores that quantify the relationship between lineage and phenotypic distances.

Core Functions
--------------

.. autosummary::
   :toctree: generated/

   PLASTRO_score
   PLASTRO_overlaps
   overlaps_to_score

Utility Functions
-----------------

.. autosummary::
   :toctree: generated/

   compute_lineage_distances
   compute_phenotype_distances
   get_overlap_score
   gini_index
   get_gini_index

Function Details
----------------

.. automodule:: plastro.overlap
   :members:
   :undoc-members:
   :show-inheritance: